@@ -1,5 +1,5 @@
 /**
- * Copyright 2001-2013 the original author or authors.
+ * Copyright 2001-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -43,7 +43,7 @@ public class SupportTest extends EasyMockSupport {
         classUnderTest.setListener(collaborator);
         collaborator.documentAdded("New Document");
         replayAll();
-        classUnderTest.addDocument("New Document", new byte[0]);
+        classUnderTest.addDocument("New Document", "content");
         verifyAll();
     }
 
@@ -62,7 +62,7 @@ public class SupportTest extends EasyMockSupport {
 
         replayAll();
 
-        classUnderTest.addDocument("Document 1", new byte[0]);
+        classUnderTest.addDocument("Document 1", "content");
         assertTrue(classUnderTest.removeDocuments("Document 1"));
 
         verifyAll();
