@@ -1,5 +1,5 @@
 /**
- * Copyright 2001-2013 the original author or authors.
+ * Copyright 2001-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,7 +18,7 @@ package org.easymock;
 import java.lang.annotation.*;
 
 /**
- * Annotation to set on a field so that {@link EasyMockRunner} or {@link EasyMockSupport#injectMocks(Object)}
+ * Annotation to set on a field so that {@link EasyMockRunner}, {@link EasyMockRule} or {@link EasyMockSupport#injectMocks(Object)}
  * will inject a mock to it.
  * <p>
  * Doing<br>
@@ -34,9 +34,19 @@ import java.lang.annotation.*;
 @Documented
 public @interface Mock {
 
-    /** Type of mock to create */
+    /** @return type of mock to create */
     MockType type() default MockType.DEFAULT;
 
-    /** Name of the mock to be created */
+    /** @return name of the mock to be created */
     String name() default "";
+
+    /**
+     * Name of the test subject field to which this mock will be assigned. Use to disambiguate the case where a mock may be assigned to multiple fields of the same type.
+     * When set, this mock will be assigned to the given field name in any test subject with a matching field name.
+     * If not set, injection is to all type-compatible fields in all test subjects.
+     * A given field name may only be used once, and there must be a matching field in at least one test subject.
+     *
+     * @return name of the field to inject to
+     **/
+    String fieldName() default "";
 }
