@@ -1,5 +1,5 @@
 /**
- * Copyright 2001-2013 the original author or authors.
+ * Copyright 2001-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,6 +24,12 @@ public final class AndroidSupport {
     static {
         try {
             Class.forName("dalvik.system.PathClassLoader");
+
+            // Also verify that dexmaker is present, if not we might
+            // be running under something like robolectric, which
+            // means we should not use dexmaker
+            Class.forName("com.google.dexmaker.Code");
+
             isAndroid = true;
         } catch (final ClassNotFoundException e) {
             isAndroid = false;
