@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2015 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -17,16 +17,18 @@ package org.easymock.internal;
 
 import java.io.Serializable;
 
+/**
+ * @author OFFIS, Tammo Freese
+ */
 public class ExpectedInvocationAndResult implements Serializable {
 
     private static final long serialVersionUID = -1951159588262854559L;
 
-    ExpectedInvocation expectedInvocation;
+    private final ExpectedInvocation expectedInvocation;
 
-    Result result;
+    private final Result result;
 
-    public ExpectedInvocationAndResult(ExpectedInvocation expectedInvocation,
-            Result result) {
+    public ExpectedInvocationAndResult(final ExpectedInvocation expectedInvocation, final Result result) {
         this.expectedInvocation = expectedInvocation;
         this.result = result;
     }
