@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2015 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -16,12 +16,21 @@
 package org.easymock.internal;
 
 import java.lang.reflect.InvocationHandler;
+import java.lang.reflect.Method;
 import java.lang.reflect.Proxy;
+import org.easymock.ConstructorArgs;
 
-public class JavaProxyFactory<T> implements IProxyFactory<T> {
+/**
+ * @author OFFIS, Tammo Freese
+ */
+public class JavaProxyFactory implements IProxyFactory {
     @SuppressWarnings("unchecked")
-    public T createProxy(Class<T> toMock, InvocationHandler handler) {
-        return (T) Proxy.newProxyInstance(toMock.getClassLoader(),
-                new Class[] { toMock }, handler);
+    public <T> T createProxy(Class<T> toMock, InvocationHandler handler,
+            Method[] mockedMethods, ConstructorArgs constructorArgs) {
+        return (T) Proxy.newProxyInstance(toMock.getClassLoader(), new Class[] { toMock }, handler);
+    }
+
+    public InvocationHandler getInvocationHandler(Object mock) {
+        return Proxy.getInvocationHandler(mock);
     }
 }
