@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2015 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,21 +19,24 @@ import java.io.Serializable;
 
 import org.easymock.IArgumentMatcher;
 
-public class Any implements IArgumentMatcher, Serializable {
+/**
+ * @author OFFIS, Tammo Freese
+ */
+public final class Any implements IArgumentMatcher, Serializable {
 
     private static final long serialVersionUID = -3743894206806704049L;
-    
-    public static final Any ANY = new Any();    
-    
+
+    public static final Any ANY = new Any();
+
     private Any() {
-        
+
     }
-    
-    public boolean matches(Object actual) {
+
+    public boolean matches(final Object actual) {
         return true;
     }
 
-    public void appendTo(StringBuffer buffer) {
+    public void appendTo(final StringBuffer buffer) {
         buffer.append("<any>");
     }
 }
