@@ -1,12 +1,12 @@
-/*
- * Copyright 2001-2009 OFFIS, Tammo Freese
- * 
+/**
+ * Copyright 2001-2015 the original author or authors.
+ *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  *     http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -19,21 +19,24 @@ import java.io.Serializable;
 
 import org.easymock.IArgumentMatcher;
 
+/**
+ * @author OFFIS, Tammo Freese
+ */
 public class Not implements IArgumentMatcher, Serializable {
 
     private static final long serialVersionUID = -5160559075998939348L;
 
     private final IArgumentMatcher first;
 
-    public Not(IArgumentMatcher first) {
+    public Not(final IArgumentMatcher first) {
         this.first = first;
     }
 
-    public boolean matches(Object actual) {
+    public boolean matches(final Object actual) {
         return !first.matches(actual);
     }
 
-    public void appendTo(StringBuffer buffer) {
+    public void appendTo(final StringBuffer buffer) {
         buffer.append("not(");
         first.appendTo(buffer);
         buffer.append(")");
