@@ -1,5 +1,5 @@
 /**
- * Copyright 2001-2013 the original author or authors.
+ * Copyright 2001-2015 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -296,4 +296,14 @@ public class RecordStateMethodCallMissingTest {
         }
     }
 
+    @Test
+    public void andVoidWithNonVoidMethod() {
+        mock.booleanReturningMethod(1);
+        try {
+            expectLastCall().andVoid();
+            fail();
+        } catch (final IllegalStateException expected) {
+            assertEquals("last method called on mock is not a void method", expected.getMessage());
+        }
+    }
 }
